==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/people/classes/UseCase/GetRole.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] ?: array()) + array("_94c782c8180766e1ff1870975a93053" . "d" => base64_decode("Um9sZSBub3QgZm91bm" . "Q="), "_f4532747e1604b7bf86d299" . "f9b9b0583" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBlcm1p" . "c3Npb24gdG8gdmlldyB0aGlzIHJv" . "bGU="));
use Claromentis\Core\ORM\Exceptions\EntityNotFoundException;
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\Role;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Exception\PermissionException;
use Claromentis\People\Filter\RoleFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\RoleRepository;




class GetRole
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $repository;
    
    
    
    
    
    public function __construct(PeopleAcl $acl, RoleRepository $_8652ba33e6ffeba02459fa9cbb320851)
    {
        $this->acl = $acl;
        $this->repository = $_8652ba33e6ffeba02459fa9cbb320851;
    }
    
    
    
    
    
    
    
    
    
    public function GetRole(SecurityContext $context, int $role_id, ?RoleFilter $_03e9164d0a343b742df4793268b80767 = null) : Role
    {
        $_03e9164d0a343b742df4793268b80767 = $_03e9164d0a343b742df4793268b80767 ?? new RoleFilter($context);
        
        
        
        
        $_d1071a032215f0eb5c4a8ef175f7049d = $this->repository->findOneWithFilter($role_id, $_03e9164d0a343b742df4793268b80767);
        if (!$_d1071a032215f0eb5c4a8ef175f7049d) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_94c782c81" . "80766e1ff1" . "870975a930" . "53d"]);
        }
        if (!$this->acl->CanViewRole($context, $_d1071a032215f0eb5c4a8ef175f7049d)) {
            throw new PermissionException($GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_f4532747e1604b7bf86d299" . "f9b9b0583"]);
        }
        return $_d1071a032215f0eb5c4a8ef175f7049d;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/people/classes/UseCase/GetRole.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"] ?: array()) + array("_94c782c8180766e1ff" . "1870975a93053d" => base64_decode("Um9sZ" . "SBub3" . "QgZm9" . "1bmQ="), "_f4532747e1604b7bf" . "86d299f9b9b0583" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBlcm1pc3Npb24gdG" . "8gdmlldyB0aGlzIHJvbGU="));
use Claromentis\Core\ORM\Exceptions\EntityNotFoundException;
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\Role;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Exception\PermissionException;
use Claromentis\People\Filter\RoleFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\RoleRepository;




class GetRole
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $repository;
    
    
    
    
    
    public function __construct(PeopleAcl $acl, RoleRepository $_8652ba33e6ffeba02459fa9cbb320851)
    {
        $this->acl = $acl;
        $this->repository = $_8652ba33e6ffeba02459fa9cbb320851;
    }
    
    
    
    
    
    
    
    
    
    public function GetRole(SecurityContext $context, int $role_id, ?RoleFilter $_03e9164d0a343b742df4793268b80767 = null) : Role
    {
        $_03e9164d0a343b742df4793268b80767 = $_03e9164d0a343b742df4793268b80767 ?? new RoleFilter($context);
        
        
        
        
        $_d1071a032215f0eb5c4a8ef175f7049d = $this->repository->findOneWithFilter($role_id, $_03e9164d0a343b742df4793268b80767);
        if (!$_d1071a032215f0eb5c4a8ef175f7049d) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_94c782c81" . "80766e1ff1" . "870975a930" . "53d"]);
        }
        if (!$this->acl->CanViewRole($context, $_d1071a032215f0eb5c4a8ef175f7049d)) {
            throw new PermissionException($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_f4532747e16" . "04b7bf86d299" . "f9b9b0583"]);
        }
        return $_d1071a032215f0eb5c4a8ef175f7049d;
    }
}
